# Stacchip change log

## 0.1.32

- Breacking change: chip iterator returns chip index values, not only image data.

## 0.1.31

- Breaking change: simplify chipper class. Indexer has to be instantiated by the user.